import 'dart:ffi';

import 'dart:io';

extension PlatformSpecific on DynamicLibrary {
  /// Platform specific file extension for dynamic libraries
  static String extension = () {
    if (Platform.isLinux || Platform.isAndroid) return '.so';
    if (Platform.isMacOS) return '.dylib';
    if (Platform.isWindows) return '.dll';
    throw UnsupportedError('Platform is not supported');
  }();

  /// Returns the full name of a library, meaning [root] + [extension].
  /// Example: on Windows, [root] = libx would return libx.dll;
  /// on Linux, it would return libx.so.
  static String fullName(String root) {
    return root + extension;
  }

  /// Opens a [DynamicLibrary] with its platform specific [fullName].
  static DynamicLibrary open(String root) {
    return DynamicLibrary.open(fullName(root));
  }
}
